import React from 'react'
import fuzzy from 'fuzzy';

import ListFilter from './filter'
import ListPoster from './poster'

export default function ListPosters(props) {
  let elmts = props.data.slice();

  // Filter the list of elements
  if (props.filter !== "") {
    const filtered = fuzzy.filter(props.filter, elmts, {
      extract: (el) => el.title
    });
    elmts = filtered.map((el) => el.original);
  }

  // Limit the number of results
  if (elmts.length > props.perPage) {
    elmts = elmts.slice(0, props.perPage);
  }

  return (
    <div className="col-xs-5 col-md-8">
      <ListFilter
        formModel={props.formModel}
        controlModel={props.controlModel}
        controlPlaceHolder={props.controlPlaceHolder}
      />
      <div className="row">
        {elmts.map(function(el, index) {
          const selected = (el.imdb_id === props.selectedImdbId) ? true : false;
          return (
            <ListPoster
              data={el}
              key={el.imdb_id}
              selected={selected}
              onClick={() => props.onClick(el.imdb_id)}
            />
          )}
        )}
      </div>
    </div>
  );
}
